<?php

namespace Litepie\Location\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Litepie\Location\Actions\LocationExim;
use Litepie\Location\Http\Requests\LocationEximRequest;

/**
 * Admin web controller class.
 */
class LocationEximController extends BaseController
{
    /**
     * Action controller function for location.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(LocationEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = LocationExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('location:location.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('location/location/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('location/location/' . $exim))
                ->redirect();
        }
    }
}
