<?php

namespace Litepie\Location\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litepie\Location\Http\Resources\LocationResource;
use Litepie\Location\Http\Resources\LocationsCollection;
use Litepie\Location\Scopes\LocationPublicScope;
use Litepie\Location\Models\Location;

class LocationPublicController extends BaseController
{

    /**
     * Show location's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Location::pushScope(new RequestScope())
            ->pushScope(new LocationPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $locations = new LocationsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('location::location.names'))
            ->view('location::public.location.index')
            ->data(compact('locations', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show location.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Location::findBySlug($slug);
        $data = new LocationResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('location::location.name'))
            ->view('location::public.location.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
