<?php

namespace Litepie\Location\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litepie\Location\Events\LocationAction as LocationActionEvent;
use Litepie\Location\Notifications\LocationAction as LocationActionNotification;
use Litepie\Actions\Concerns\AsAction;

class LocationAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the LocationActionEvent.
     *
     * @param   LocationActionEvent  $event
     * @return mixed
     */
    public function handle(LocationActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $location.
     *
     * @param   LocationActionEvent  $event
     * @return void
     */
    public function create(LocationActionEvent $event)
    {
        $client = $event->$location->client;
        Notification::send($client, new LocationActionNotification($event));
    }

    /**
     * Handle the LocationActionEvent as a listener.
     *
     * @param   LocationActionEvent  $event
     * @return mixed
     */
    public function asListener(LocationActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   LocationActionEvent  $event
     * @return bool
     */
    private function isAllowed(LocationActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
