<?php

namespace Litepie\Location\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litepie\Location\Events\LocationWorkflow as LocationWorkflowEvent;
use Litepie\Location\Notifications\LocationWorkflow as LocationWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class LocationWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(LocationWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $location is submitted.
     *
     * @param LocationWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(LocationWorkflowEvent $event)
    {
        $client = $event->$location->client;
        Notification::send($client, new LocationWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $location is published.
     *
     * @param LocationWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(LocationWorkflowEvent $event)
    {
        $client = $event->$location->client;
        Notification::send($client, new LocationWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $location is approved.
     *
     * @param LocationWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(LocationWorkflowEvent $event)
    {
        $client = $event->$location->client;
        Notification::send($client, new LocationWorkflowNotification($event));
    }

    /**
     * Handles the $location workflow event as a listener.
     *
     * @param LocationWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(LocationWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
