<?php
namespace Litepie\Location\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litepie\Location\Events\LocationAction as LocationActionEvent;
use Litepie\Location\Models\Location;

class LocationAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $location;

    protected $action;

    /**
     * Create a new notification instance.
     *
     * @param LocationActionEvent $location
     * @param string $action
     */
    public function __construct(LocationActionEvent $location, string $action)
    {
        $this->action = $action;
        $this->location = $location;
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Location Approved - ' . config('app.name'))
            ->view('location::location.email.action', ['data' => $this->location]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
