<?php

namespace Litepie\Location\Policies;

use Litepie\Location\Models\Location;
use Litepie\User\Interfaces\UserPolicyInterface;

trait LocationAction
{

    /**
     * Determine if the given user can approve the given location.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function copy(UserPolicyInterface $authUser, Location $location)
    {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('location.location.action.copy')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given location.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    function empty(UserPolicyInterface $authUser, Location $location) {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('location.location.action.empty')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given location.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function transfer(UserPolicyInterface $authUser, Location $location)
    {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('location.location.action.transfer')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given location.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function delete(UserPolicyInterface $authUser, Location $location)
    {


        if ($authUser->canDo('location.location.action.delete')) {
            return true;
        }

        return false;
    }


}
